@@ -9,7 +9,7 @@ def search(
     field: str = 'content',
     query: Q = None,
     sources: List = [],
-    highlights: Dict = {},
+    highlight: Dict = {},
     extras: Dict = {}
 ):
 
